==> apollopay-1.0.1.tar.gz: lib/src/api/entities/user_entity.dart <==
import 'dart:convert';

import 'package:apollopay/src/api/entities/entity_entity.dart';
import 'package:mongo_dart/mongo_dart.dart';

enum UserType { none, apollocrypto, apollopay, apollodata, admin }

class User extends Entity {
  String? id;
  String email;
  String? firstName;
  String? lastName;
  String? firebaseId;
  String? image;
  UserType type;

  String get displayName => '$firstName $lastName';

  User(
      {required this.id,
      required this.email,
      this.firstName,
      this.lastName,
      this.firebaseId,
      this.image,
      this.type = UserType.none});

  User copyWith(
      {String? id,
      String? email,
      String? firstName,
      String? lastName,
      String? firebaseId,
      String? image,
      UserType? type}) {
    return User(
        id: id ?? this.id,
        email: email ?? this.email,
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        firebaseId: firebaseId ?? this.firebaseId,
        image: image ?? this.image,
        type: type ?? this.type);
  }

  Map<String, dynamic> toMap() {
    return {
      '_id': id,
      'email': email,
      'firstName': firstName,
      'lastName': lastName,
      'firebaseId': firebaseId,
      'image': image,
      'type': type.index
    };
  }

  factory User.fromMap(Map<String, dynamic> map) {
    return User(
        id: map['_id'] is ObjectId
            ? map['_id'].toHexString()
            : map['_id'].toString(),
        email: map['email'] ?? '',
        firstName: map['firstName'],
        lastName: map['lastName'],
        firebaseId: map['firebaseId'],
        image: map['image'],
        type: (map['type'] != null)
            ? UserType.values[int.parse(map['type'].toString())]
            : UserType.none);
  }

  factory User.fromJson(String source) => User.fromMap(json.decode(source));

  @override
  String toString() {
    return 'User(id: $id, email: $email, firstName: $firstName, lastName: $lastName, firebaseId: $firebaseId, type: ${type.name})';
  }

  @override
  bool operator ==(Object? other) {
    if (identical(this, other)) return true;

    return other is User &&
        other.id == id &&
        other.email == email &&
        other.firstName == firstName &&
        other.lastName == lastName &&
        other.firebaseId == firebaseId &&
        other.image == image;
  }

  @override
  int get hashCode {
    return id.hashCode ^
        email.hashCode ^
        firstName.hashCode ^
        lastName.hashCode ^
        firebaseId.hashCode;
  }
}

==> apollopay-1.0.4.tar.gz: lib/src/api/entities/user_entity.dart <==
import 'dart:convert';

import 'package:apollopay/src/api/entities/entity_entity.dart';
import 'package:mongo_dart/mongo_dart.dart';

enum UserType { none, apollocrypto, apollopay, apollodata, admin }

class User extends Entity {
  String? id;
  String email;
  String? firstName;
  String? lastName;
  String? firebaseId;
  String? image;
  UserType type;

  String get displayName => '$firstName $lastName';

  User(
      {required this.id,
      required this.email,
      this.firstName,
      this.lastName,
      this.firebaseId,
      this.image,
      this.type = UserType.none});

  @override
  User copyWith(
      {String? id,
      String? email,
      String? firstName,
      String? lastName,
      String? firebaseId,
      String? image,
      UserType? type}) {
    return User(
        id: id ?? this.id,
        email: email ?? this.email,
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        firebaseId: firebaseId ?? this.firebaseId,
        image: image ?? this.image,
        type: type ?? this.type);
  }

  @override
  Map<String, dynamic> toMap({bool withId = true}) {
    return {
      '_id': id,
      'email': email,
      'firstName': firstName,
      'lastName': lastName,
      'firebaseId': firebaseId,
      'image': image,
      'type': type.index
    };
  }

  factory User.fromMap(Map<String, dynamic> map) {
    return User(
        id: map['_id'] is ObjectId
            ? map['_id'].toHexString()
            : map['_id'].toString(),
        email: map['email'] ?? '',
        firstName: map['firstName'],
        lastName: map['lastName'],
        firebaseId: map['firebaseId'],
        image: map['image'],
        type: (map['type'] != null)
            ? UserType.values[int.parse(map['type'].toString())]
            : UserType.none);
  }

  factory User.fromJson(String source) => User.fromMap(json.decode(source));

  @override
  String toString() {
    return 'User(id: $id, email: $email, firstName: $firstName, lastName: $lastName, firebaseId: $firebaseId, type: ${type.name})';
  }

  @override
  bool operator ==(Object? other) {
    if (identical(this, other)) return true;

    return other is User &&
        other.id == id &&
        other.email == email &&
        other.firstName == firstName &&
        other.lastName == lastName &&
        other.firebaseId == firebaseId &&
        other.image == image;
  }

  @override
  int get hashCode {
    return id.hashCode ^
        email.hashCode ^
        firstName.hashCode ^
        lastName.hashCode ^
        firebaseId.hashCode;
  }
}
